@@ -28,7 +28,7 @@
 use strict ;
 
 our $PRG = 'mirmon' ;
-our $VER = "2.5" ;
+our $VER = "2.6" ;
 
 our $DEF_TIMEOUT = 300 ;
 our $HIST        = 14 ;
@@ -318,6 +318,22 @@ sub get_regions
     close REGS ;
   }
 
+sub _cmp_ccs
+  { my $ccs = shift ;
+    my $x  = shift ;
+    my $y  = shift ;
+    my $xx = $ccs -> { $x } ;
+    my $yy = $ccs -> { $y } ;
+    if ( ! defined $xx and ! defined $yy )
+      { $x cmp $y ; }
+    elsif ( ! defined $xx )
+      { -1 ; }
+    elsif ( ! defined $yy )
+      { +1 ; }
+    else
+      { $xx cmp $yy ; }
+  }
+
 sub _pr_round
   { my $x = shift ;
     my $i = int $x ;
@@ -1106,10 +1122,11 @@ $histo_top
 HEAD
 
     for my $reg
-      ( sort
-       { ( lc $CCS -> { $a } || $a ) cmp ( lc $CCS -> { $b } || $b ) ; }
-       keys %tab
-      )
+      ( sort { _cmp_ccs $CCS, $a, $b } keys %tab )
+#      { ( $CCS -> { $a } ? lc ( $CCS -> { $a } ) : $a )
+#    cmp ( $CCS -> { $b } ? lc ( $CCS -> { $b } ) : $b )
+#      } keys %tab
+#     )
       { my $mirrors = $tab { $reg } ;
 
         my $ccs = exists $CCS -> { $reg } ? $CCS -> { $reg } : $reg ;
@@ -1810,7 +1827,7 @@ mirmon(1)
   <A HREF="http://www.cs.uu.nl/">Computer Science Department</A>,
   <A HREF="http://www.uu.nl/">Utrecht University</A>
   <BR>
-  mirmon-2.5 - Sat Mar 24 09:07:39 2012 ; henkp
+  mirmon-2.6 - Fri Mar 30 09:56:03 2012 ; henkp
 
 =end html
 
@@ -1819,7 +1836,7 @@ mirmon(1)
   (c) 2003-2012 Henk P. Penning
   Computer Science Department, Utrecht University
   http://people.cs.uu.nl/henkp/ -- penning@cs.uu.nl
-  mirmon-2.5 - Sat Mar 24 09:07:39 2012 ; henkp
+  mirmon-2.6 - Fri Mar 30 09:56:03 2012 ; henkp
 
 =end man
 
@@ -1828,7 +1845,7 @@ mirmon(1)
   (c) 2003-2012 Henk P. Penning
   Computer Science Department, Utrecht University
   http://people.cs.uu.nl/henkp/ -- penning@cs.uu.nl
-  mirmon-2.5 - Sat Mar 24 09:07:39 2012 ; henkp
+  mirmon-2.6 - Fri Mar 30 09:56:03 2012 ; henkp
 
 =end text
 
